@@ -26,7 +26,7 @@ class RestCall(Logger):
     _time_tracker_df  = DataFrame()
     _track_time = True
 
-    def __init__(*,self, base_url, user=None, password=None, basic_auth=None, track_time=False,log_level=INFO):
+    def __init__(self,*, base_url, user=None, password=None, basic_auth=None, track_time=False,log_level=INFO):
         super().__init__(level=log_level)
         if base_url[-1]=='/': 
             base_url=base_url[:-1]
